@@ -4,10 +4,10 @@ pub struct Fibonacci {
     y: usize,
 }
 
-/// First numbers are following: [1, 2, 3, 5, 8, 13, 21, 34, 55, 89, ...]
+/// Sequence: [0, 1, 1, 2, 3, 5, 8, 13, 21, 34, 55, 89, ...]
 impl Fibonacci {
     pub fn new() -> Self {
-        Self { x: 0, y: 1 }
+        Self { x: 0, y: 0 }
     }
 }
 
@@ -15,9 +15,14 @@ impl Iterator for Fibonacci {
     type Item = usize;
 
     fn next(&mut self) -> Option<Self::Item> {
-        let z = self.x + self.y;
-        self.x = self.y;
-        self.y = z;
-        Some(z)
+        if self.y == 0 {
+            self.y = 1;
+            Some(0)
+        } else {
+            let z = self.x + self.y;
+            self.x = self.y;
+            self.y = z;
+            Some(self.x)
+        }
     }
 }
