@@ -1,7 +1,7 @@
 use funtools::Prime;
 
 #[test]
-fn primes_to_100() {
+fn prime_100() {
     let valid = vec![
         2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 79, 83, 89,
         97,
